@@ -6,7 +6,6 @@ from sqlalchemy.orm import class_mapper, joinedload
 from sqlalchemy.exc import IntegrityError
 from sqlalchemy import MetaData
 from sqlalchemy import func
-from app import db
 
 import sqlalchemy as sa
 import sys
@@ -34,10 +33,10 @@ class SQLAModel(DataModel):
     SQLAModel
     Implements SQLA support methods for views
     """
-    db_session = None
+    session = None
     
-    def __init__(self, obj, db_session = None):
-        db_session = db_session
+    def __init__(self, obj, session = None):
+        self.session = session
         DataModel.__init__(self, obj)
 
     
@@ -74,13 +73,13 @@ class SQLAModel(DataModel):
     def query_simple_group(self, group_by = '', filters = {}, order_column = '', order_direction = ''):
         try:
             rel_model, rel_direction = self._get_related_model(group_by)
-            query = db.session.query(rel_model,func.count(self.obj.id))
+            query = self.session.query(rel_model,func.count(self.obj.id))
             query = query.join(rel_model, getattr(self.obj,group_by))
             query = self._get_base_query(query = query, filters = filters, order_column = order_column, order_direction = order_direction)
             query = query.group_by(rel_model)
             return query.all()
         except:
-            query = db.session.query(rel_model,func.count(self.obj.id))
+            query = self.session.query(rel_model,func.count(self.obj.id))
             query = self._get_base_query(query = query, filters = filters, order_column = order_column, order_direction = order_direction)
             query = query.group_by(group_by)
             return query.all()
@@ -144,49 +143,49 @@ class SQLAModel(DataModel):
     """
     def add(self, item):
         try:
-            db.session.add(item)
-            db.session.commit()
+            self.session.add(item)
+            self.session.commit()
             flash(unicode(self.add_row_message),'success')
             return True
         except IntegrityError as e:
             flash(unicode(self.add_integrity_error_message),'warning')
-            db.session.rollback()
+            self.session.rollback()
             return False
         except:
             flash(unicode(self.general_error_message + ' '  + str(sys.exc_info()[0])),'danger')
-            db.session.rollback()
+            self.session.rollback()
             return False
 
     def edit(self, item):
         try:
-            db.session.merge(item)
-            db.session.commit()
+            self.session.merge(item)
+            self.session.commit()
             flash(unicode(self.edit_row_message),'success')
             return True
         except IntegrityError as e:
             flash(unicode(self.edit_integrity_error_message),'warning')
-            db.session.rollback()
+            self.session.rollback()
             return False
         except:
             flash(unicode(self.general_error_message + ' '  + str(sys.exc_info()[0])),'danger')
-            db.session.rollback()
+            self.session.rollback()
             return False
                 
     
     def delete(self, item):
         try:
             self._delete_files(item)
-            db.session.delete(item)
-            db.session.commit()
+            self.session.delete(item)
+            self.session.commit()
             flash(unicode(self.delete_row_message),'success')
             return True
         except IntegrityError as e:
             flash(unicode(self.delete_integrity_error_message),'warning')
-            db.session.rollback()
+            self.session.rollback()
             return False
         except:
             flash(unicode(self.general_error_message + ' '  + str(sys.exc_info()[0])),'danger')
-            db.session.rollback()
+            self.session.rollback()
             return False
         
         
@@ -205,15 +204,15 @@ class SQLAModel(DataModel):
                 
         
     def _delete_files(self, item):
-        fm = FileManager()
-        im = ImageManager()
         for file_col in self.get_file_column_list():
             if self.is_file(file_col):
                 if getattr(item,file_col):
+                    fm = FileManager()
                     fm.delete_file(getattr(item, file_col))
         for file_col in self.get_image_column_list():
             if self.is_image(file_col):
                 if getattr(item,file_col):
+                    im = ImageManager()
                     im.delete_file(getattr(item,file_col))
 
     """
