@@ -1,6 +1,6 @@
 from flask import g, request, current_app
 from flask.ext.login import current_user
-from flask import render_template, flash, redirect,url_for
+from flask import flash, redirect,url_for
 from models import is_item_public
 
 def has_access(f):
@@ -22,4 +22,3 @@ def has_access(f):
         return redirect(url_for("authview.login"))
     return wrap
 
-    
